==> rwgcod.db_2.0.1.tar.gz: rwgcod.db/man/rwgcod_dbconn.Rd <==
\name{rwgcod_dbconn}

\alias{rwgcod_dbconn}
\alias{rwgcod_dbfile}
\alias{rwgcod_dbschema}
\alias{rwgcod_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  rwgcod_dbconn()
  rwgcod_dbfile()
  rwgcod_dbschema(file="", show.indices=FALSE)
  rwgcod_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{rwgcod_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{rwgcod_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{rwgcod_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{rwgcod_dbschema} prints the schema definition of the
  package annotation DB.

  \code{rwgcod_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{rwgcod_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{rwgcod_dbfile}: a character string with the path to the
  package annotation DB.

  \code{rwgcod_dbschema}: none (invisible \code{NULL}).

  \code{rwgcod_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(rwgcod_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by rwgcod_dbconn() was created with:
  dbConnect(SQLite(), dbname=rwgcod_dbfile(), cache_size=64000, synchronous=0)

  rwgcod_dbschema()

  rwgcod_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> rwgcod.db_2.18.0.tar.gz: rwgcod.db/man/rwgcod_dbconn.Rd <==

\name{rwgcod_dbconn}

\alias{rwgcod_dbconn}
\alias{rwgcod_dbfile}
\alias{rwgcod_dbschema}
\alias{rwgcod_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  rwgcod_dbconn()
  rwgcod_dbfile()
  rwgcod_dbschema(file="", show.indices=FALSE)
  rwgcod_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{rwgcod_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{rwgcod_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{rwgcod_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{rwgcod_dbschema} prints the schema definition of the
  package annotation DB.

  \code{rwgcod_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{rwgcod_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{rwgcod_dbfile}: a character string with the path to the
  package annotation DB.

  \code{rwgcod_dbschema}: none (invisible \code{NULL}).

  \code{rwgcod_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(rwgcod_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by rwgcod_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=rwgcod_dbfile(), cache_size=64000,
  synchronous=0)

  rwgcod_dbschema()

  rwgcod_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
